@@ -7,7 +7,7 @@ use warnings;
 use URI;
 use REST::Client;
 
-our $VERSION = '0.03';  # Version of your module
+our $VERSION = '0.04';  # Version of your module
 
 sub new {
     my ($class, %args) = &_grok_args;
@@ -387,6 +387,10 @@ Attaches files to a Jira issue.
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/kawamurashingo/JIRA-REST-Lite>
+
 =head1 AUTHOR
 
 Kawamura Shingo <pannakoota@gmail.com>
